package com.phm.manage.service.impl;

import com.phm.manage.domain.FeedbackRawData;
import com.phm.manage.mapper.FeedbackRawDataMapper;
import com.phm.manage.service.IFeedbackRawDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 反馈的源数据Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class FeedbackRawDataServiceImpl implements IFeedbackRawDataService {
    @Autowired
    private FeedbackRawDataMapper feedbackRawDataMapper;

    /**
     * 查询反馈的源数据
     *
     * @param id 反馈的源数据主键
     * @return 反馈的源数据
     */
    @Override
    public FeedbackRawData selectFeedbackRawDataById(Long id) {
        return feedbackRawDataMapper.selectFeedbackRawDataById(id);
    }

    /**
     * 查询反馈的源数据列表
     *
     * @param feedbackRawData 反馈的源数据
     * @return 反馈的源数据
     */
    @Override
    public List<FeedbackRawData> selectFeedbackRawDataList(FeedbackRawData feedbackRawData) {
        return feedbackRawDataMapper.selectFeedbackRawDataList(feedbackRawData);
    }

    /**
     * 新增反馈的源数据
     *
     * @param feedbackRawData 反馈的源数据
     * @return 结果
     */
    @Override
    public int insertFeedbackRawData(FeedbackRawData feedbackRawData) {
        return feedbackRawDataMapper.insertFeedbackRawData(feedbackRawData);
    }

    /**
     * 修改反馈的源数据
     *
     * @param feedbackRawData 反馈的源数据
     * @return 结果
     */
    @Override
    public int updateFeedbackRawData(FeedbackRawData feedbackRawData) {
        return feedbackRawDataMapper.updateFeedbackRawData(feedbackRawData);
    }

    /**
     * 批量删除反馈的源数据
     *
     * @param ids 需要删除的反馈的源数据主键
     * @return 结果
     */
    @Override
    public int deleteFeedbackRawDataByIds(Long[] ids) {
        return feedbackRawDataMapper.deleteFeedbackRawDataByIds(ids);
    }

    /**
     * 删除反馈的源数据信息
     *
     * @param id 反馈的源数据主键
     * @return 结果
     */
    @Override
    public int deleteFeedbackRawDataById(Long id) {
        return feedbackRawDataMapper.deleteFeedbackRawDataById(id);
    }
}
